django_premailer.templatetags package
=====================================

Submodules
----------

django_premailer.templatetags.premailer module
----------------------------------------------

.. automodule:: django_premailer.templatetags.premailer
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_premailer.templatetags
    :members:
    :undoc-members:
    :show-inheritance:
